==> seedsui-react-5.5.91.tgz: package/lib/Location/Modal/Map/Choose.js <==
var _excluded = ["ak", "value", "onChange"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useRef, useEffect, useState } from 'react';
import MapUtil from "./../../../MapUtil";
import Page from "./../../../Page";
import Container from "./../../../Container";
import Footer from "./../../../Footer";
import Notice from "./../../../Notice";
import locale from "./../../../locale";
import Instance from "./instance";
import Control from "./Control";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var center = '江苏省,南京市';

function MapView(_ref) {
  var _value, _value2;

  var ak = _ref.ak,
      _ref$value = _ref.value,
      argValue = _ref$value === void 0 ? null : _ref$value,
      onChange = _ref.onChange,
      props = _objectWithoutProperties(_ref, _excluded);

  var mapRef = useRef(null);
  var instance = useRef(null);

  var _useState = useState(argValue),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = useState(true),
      _useState4 = _slicedToArray(_useState3, 2),
      loading = _useState4[0],
      setLoading = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      errMsg = _useState6[0],
      setErrMsg = _useState6[1];

  useEffect(function () {
    setValue(argValue);
  }, [JSON.stringify(argValue)]); // eslint-disable-line

  useEffect(function () {
    if (!window.BMap && !ak) {
      setErrMsg(locale('请传入百度地图ak', 'hint_map_ak'));
      return;
    }

    MapUtil.load({
      ak: ak,
      success: function success() {
        initData();
      },
      fail: function fail() {
        setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      }
    }); // 移除组件时注销

    return function () {
      if (instance.current) {
        instance.current.destroy();
      }
    };
  }, []); // eslint-disable-line
  // 绘制标记点

  useEffect(function () {
    handleMarker();
  }, [loading]); // eslint-disable-line
  // 初始化地图

  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      return;
    }

    console.log('初始化地图' + center);

    if (!mapRef.current) {
      setErrMsg(locale('地图容器不存在', 'hint_map_no_container'));
      return;
    }

    var temp = new Instance();
    temp.initMap(mapRef.current, center, function (result) {
      if (typeof result === 'string') {
        setErrMsg(result);
        return;
      }

      instance.current = temp; // 拖拽选点

      instance.current.initDragPoint(function (newValue) {
        if (newValue) {
          setValue(newValue);
        } else {
          handleReset();
        }
      });
      setErrMsg('');
      setLoading(false);
    });
  } // 绘制标记点


  function handleMarker() {
    if (instance.current && value && value.latitude && value.longitude) {
      var point = [value.longitude, value.latitude];
      instance.current.drawMarker(point);
      setTimeout(function () {
        handleReset();
      }, 200);
    }
  } // 还原位置


  function handleReset() {
    if (value && value.longitude && value.latitude) {
      instance.current.centerToPoint([value.longitude, value.latitude]);
    }
  } // 修改位置


  function handleLocation(newValue) {
    value = newValue;
    setValue(newValue); // 绘制标记点

    handleMarker();
  } // 点击确定


  function handleSubmit() {
    if (onChange) onChange(value);
  }

  return /*#__PURE__*/_jsxs(Page, _objectSpread(_objectSpread({}, props), {}, {
    children: [/*#__PURE__*/_jsxs(Container, {
      children: [/*#__PURE__*/_jsx("div", {
        ref: mapRef,
        className: "map-container"
      }), /*#__PURE__*/_jsx(Control.Location, {
        instance: instance,
        value: value,
        onChange: handleLocation
      })]
    }), /*#__PURE__*/_jsxs(Footer, {
      className: "map-footer",
      children: [/*#__PURE__*/_jsxs("div", {
        className: "map-footer-content",
        onClick: handleReset,
        children: [/*#__PURE__*/_jsx("p", {
          className: "map-footer-content-caption",
          children: locale('当前位置', 'current_location')
        }), /*#__PURE__*/_jsx("p", {
          className: "map-footer-content-sndcaption",
          children: ((_value = value) === null || _value === void 0 ? void 0 : _value.value) || ''
        })]
      }), ((_value2 = value) === null || _value2 === void 0 ? void 0 : _value2.value) && /*#__PURE__*/_jsx("span", {
        className: "map-footer-submit",
        onClick: handleSubmit,
        children: locale('确定', 'ok')
      })]
    }), errMsg && /*#__PURE__*/_jsx(Notice, {
      caption: errMsg
    })]
  }));
}

export default MapView;

==> seedsui-react-5.5.92.tgz: package/lib/Location/Modal/Map/Choose.js <==
var _excluded = ["ak", "value", "onChange"];

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useRef, useEffect, useState } from 'react';
import MapUtil from "./../../../MapUtil";
import Page from "./../../../Page";
import Container from "./../../../Container";
import Footer from "./../../../Footer";
import Notice from "./../../../Notice";
import locale from "./../../../locale";
import Instance from "./instance";
import Control from "./Control";
var center = '江苏省,南京市';

function MapView(_ref) {
  var _value, _value2;

  var ak = _ref.ak,
      _ref$value = _ref.value,
      argValue = _ref$value === void 0 ? null : _ref$value,
      onChange = _ref.onChange,
      props = _objectWithoutProperties(_ref, _excluded);

  var mapRef = useRef(null);
  var instance = useRef(null);

  var _useState = useState(argValue),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = useState(true),
      _useState4 = _slicedToArray(_useState3, 2),
      loading = _useState4[0],
      setLoading = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      errMsg = _useState6[0],
      setErrMsg = _useState6[1];

  useEffect(function () {
    setValue(argValue);
  }, [JSON.stringify(argValue)]); // eslint-disable-line

  useEffect(function () {
    if (!window.BMap && !ak) {
      setErrMsg(locale('请传入百度地图ak', 'hint_map_ak'));
      return;
    }

    MapUtil.load({
      ak: ak,
      success: function success() {
        initData();
      },
      fail: function fail() {
        setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      }
    }); // 移除组件时注销

    return function () {
      if (instance.current) {
        instance.current.destroy();
      }
    };
  }, []); // eslint-disable-line
  // 绘制标记点

  useEffect(function () {
    handleMarker();
  }, [loading]); // eslint-disable-line
  // 初始化地图

  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      return;
    }

    console.log('初始化地图' + center);

    if (!mapRef.current) {
      setErrMsg(locale('地图容器不存在', 'hint_map_no_container'));
      return;
    }

    var temp = new Instance();
    temp.initMap(mapRef.current, center, function (result) {
      if (typeof result === 'string') {
        setErrMsg(result);
        return;
      }

      instance.current = temp; // 拖拽选点

      instance.current.initDragPoint(function (newValue) {
        if (newValue) {
          setValue(newValue);
        } else {
          handleReset();
        }
      });
      setErrMsg('');
      setLoading(false);
    });
  } // 绘制标记点


  function handleMarker() {
    if (instance.current && value && value.latitude && value.longitude) {
      var point = [value.longitude, value.latitude];
      instance.current.drawMarker(point);
      setTimeout(function () {
        handleReset();
      }, 200);
    }
  } // 还原位置


  function handleReset() {
    if (value && value.longitude && value.latitude) {
      instance.current.centerToPoint([value.longitude, value.latitude]);
    }
  } // 修改位置


  function handleLocation(newValue) {
    value = newValue;
    setValue(newValue); // 绘制标记点

    handleMarker();
  } // 点击确定


  function handleSubmit() {
    if (onChange) onChange(value);
  }

  return /*#__PURE__*/React.createElement(Page, props, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement("div", {
    ref: mapRef,
    className: "map-container"
  }), /*#__PURE__*/React.createElement(Control.Location, {
    instance: instance,
    value: value,
    onChange: handleLocation
  })), /*#__PURE__*/React.createElement(Footer, {
    className: "map-footer"
  }, /*#__PURE__*/React.createElement("div", {
    className: "map-footer-content",
    onClick: handleReset
  }, /*#__PURE__*/React.createElement("p", {
    className: "map-footer-content-caption"
  }, locale('当前位置', 'current_location')), /*#__PURE__*/React.createElement("p", {
    className: "map-footer-content-sndcaption"
  }, ((_value = value) === null || _value === void 0 ? void 0 : _value.value) || '')), ((_value2 = value) === null || _value2 === void 0 ? void 0 : _value2.value) && /*#__PURE__*/React.createElement("span", {
    className: "map-footer-submit",
    onClick: handleSubmit
  }, locale('确定', 'ok'))), errMsg && /*#__PURE__*/React.createElement(Notice, {
    caption: errMsg
  }));
}

export default MapView;
